emailpgp
=========

[![PyPI](https://img.shields.io/pypi/v/emailpgp.svg)](https://pypi.python.org/pypi/emailpg)

Extend Python email classes to add MIME multipart/pgp-encrypted
type messages.

License
--------
emailpgp is copyright 2017 by juga ( juga at riseup dot net) and is licensed under the MIT license.
